*MASTER DO-FILE: SETTINGS AND RUN DO-FILES
*make sure that current working directory to the folder with the RUN_ALL.do file

************************************************************************************************************************
***														SETTINGS											  		 ***
************************************************************************************************************************

log using replication_log, replace

*Stata settings
clear all
set matsize 11000
set maxvar 32000
set mem 1000m 
set more off

*Define paths
global path : pwd
global gphpath "${path}/figures and tables"

*Create folders
cap mkdir "${path}/currentdata"
cap mkdir "${path}/figures and tables"
cap mkdir "${path}/currentdata/temp"

*Set working directory
cd "${path}/currentdata"

*Datasets
global dataset "pilotsmonthly"
global dataset_daily "pilotsdaily"
global datasetCEM "pilotsmonthly_CEM"


*Scheme for figures
set scheme tufte


************************************************************************************************************************
***													RUN EVERYTHING											  		 ***
************************************************************************************************************************

*Collapse main dataset to monthly and run analysis
do $path/code/1-collapse_panel_to_monthly.do
python script $path/code/create_socialuniverse_variables.py
do $path/code/2-panel_analysis.do
*Create CEM dataset and run analysis
do $path/code/3-create_CEM.do
do $path/code/4-CEM_analysis.do
*Create flight log dataset and run analysis
do $path/code/5-flightlog_daily_analysis.do
do $path/code/6-flightlog_monthly_analysis.do



************************************************************************************************************************
***														CLEAN												  		 ***
************************************************************************************************************************


*Delete temp folder
shell rd "temp" /s /q


log close
