* THIS DO-FILE COLLAPSES THE PILOT-DAY PANEL TO A PILOT-MONTH PANEL

**************************************************************************************************************
****                                    PLAN OF THE PROCEDURE                                             ****
****                                                                                                      ****
****        1. COLLAPSE DAILY DATA TO MONTHLY DATA														  ****
****  		a. Collapse							               					                 		  ****
****        b. Adjust variables                                              							  ****
****        2. ADD PAST PEER VARIABLES							                                  	  	  ****
****           a. Create past peer lists                                                                  ****
****           b. Add past peer variables															  	  ****
**************************************************************************************************************




**************************************************************************************************************
****        					1. COLLAPSE DAILY DATA TO MONTHLY DATA									  ****
****        								a. Collapse													  ****
**************************************************************************************************************


*Use
use $path/rawdata/pilotsdaily, replace
		   
*Store variable names
foreach v of var * {
	local l`v' : variable label `v'
	if `"`l`v''"' == "" {
		local l`v' "`v'"
	}
}

*Collapse
sort name_id time_id
collapse (last) cvic cvic_scwadj												///
				id_squadron id_group front 										///
				base_latitude base_longitude base_id							///
				Plane BF109D BF109E BF109F BF109G BF109K FW190A FW190D			///
				birth_latitude1 birth_longitude1 birth_latitude2 				///
				birth_longitude2 birth_latitude3 birth_longitude3				///
				vicdays_per_month		/// (these are monthly variables ->take last)
				scw_d			///
		 (sum) vic_mentions_new vic		///
		 (max) exit		///
		 , by(name_id ym_time_id)

*Restore variable names
foreach v of var * {
	label variable `v' "`l`v''"
}

**************************************************************************************************************	 
****        							b. Adjust variables												  ****
**************************************************************************************************************
			   
*Time variables
egen min_ym_time_id = min(ym_time_id)
gen t = ym_time_id + (1-min_ym_time_id)
drop min_ym_time_id


*Mentionperiod_n
gen mentionperiod_n = 0
by ym_time_id, sort: egen vic_mentions_new_month = max(vic_mentions_new)
replace mentionperiod_n = 1 if vic_mentions_new_month > 0
drop vic_mentions_new_month

*Experience variables
by name_id (ym_time_id), sort: gen exp = _n
by name_id (ym_time_id), sort: gen exp_scw = _n
replace exp_scw = exp_scw + 32 if scw_d == 1		//Same definition as for daily, but aggregated to monthly

*Pilot quality
gen pilot_quality = (cvic-vic)/exp
gen pilot_quality_scwadj = (cvic_scwadj-vic)/exp_scw

*Time_id
rename ym_time_id time_id


***SAVE
*Label
label variable exp_scw 				"pilot's experience in months adjusted for SCW"
label variable t 					"months since start of panel" 
label variable pilot_quality 		"pilot's quality in months"
label variable pilot_quality_scwadj	"pilot's quality in months adjusted for SCW"
label variable mentionperiod_n		"=1 if a pilot was mention in this time period"
*Adjust labels from daily to monthly for victories, qing, group, squadron, and front
foreach var of varlist front vic{
  local varlabel : var label `var'
  local newname : subinstr local varlabel "day" "month", all
  label variable `var' "`newname'"
}
*Save
save $path/currentdata/pilotsmonthly1, replace
 
 
 
**************************************************************************************************************
****        							2. ADD PAST PEER VARIABLES										  ****
**************************************************************************************************************
global dataset_input "pilotsmonthly1"
global dataset_output "pilotsmonthly2"

**************************************************************************************************************
****									a. Create past peer lists										  ****
**************************************************************************************************************
*Past squadron peers
do $path/code/helper_programs/build_squadronpeerlists_monthly.do

*Alternative peer lists: group peers and base peers
do $path/code/helper_programs/build_grouplists_monthly.do
do $path/code/helper_programs/build_baselists_monthly.do



**************************************************************************************************************
****									b. Add past peer variables										  ****
**************************************************************************************************************

***Prepare data
use $dataset_input.dta, clear
gen anymention = 0
replace anymention = 1 if vic_mentions_new >0 & vic_mentions_new !=.
save  $dataset_output, replace

***Add variables
*Pastpeer
do "$path/code/helper_programs/gen_pastpeer_monthly.do"
gen_pastpeer_monthly anymention $dataset_output
rename pastpeerofanymention pastpeerofmentioned_n
drop mentionperiod_n
rename anymentionperiod mentionperiod_n
save  $dataset_output, replace

*Everpeer
do "$path/code/helper_programs/gen_everpeer_monthly.do"
gen_everpeer_monthly anymention $dataset_output
rename everpeer_anymention everpeer
save  $dataset_output, replace


***SAVE
*Keep
drop evermentioned_id peer_comp
*Label
label variable pastpeerofmentioned_n "=1 if former peer is mentioned"
label variable anymention 			 "=1 if mentioned"
label variable mentionperiod_n		 "=1 if a peer is mention in this period"
label variable everpeer				 "=1 if pilot is ever a former peer of a mentioned pilot"
*Save
compress
xtset name_id time_id
save $path/currentdata/pilotsmonthly, replace
*Erase
erase $path/currentdata/pilotsmonthly1.dta
erase $path/currentdata/pilotsmonthly2.dta




