*THIS DO-FILE RUNS ALL ANALYSES WITH THE CEM DATA

************************************************************************************************************************
***												TABLE 3: DIFF-IN-DIFF												 ***
************************************************************************************************************************
use $datasetCEM.dta, clear
stset exp_scw, id(event_id) failure(exit==1)

***VICTORIES
est clear
***Column 1: all time periods
eststo m1: xi: reghdfe vic post_x_treatment, cl(id_squadron) a(name_id event_id et)
	*Add meab vic
	qui sum vic if !missing(id_squadron)
	estadd scalar mean = r(mean)
	*Add FEs
	estadd local pilotFE "Y"
	estadd local eventFE "Y"
	estadd local etFE "Y"

***Column 2: +/-6 time window
preserve
	keep if event_time >= -6 & event_time <= 6
	eststo m2: xi: reghdfe vic post_x_treatment, cl(id_squadron) a(name_id event_id et)
		*Add meab vic
		qui sum vic if !missing(id_squadron)
		estadd scalar mean = r(mean)
		*Add FEs
		estadd local pilotFE "Y"
		estadd local eventFE "Y"
		estadd local etFE "Y"
restore

esttab m1 m2 using "$gphpath/table3_vic.tex", 																///
		   se r2 star(* .1 ** .05 *** .01) b(%9.3f) booktabs 												///
		   keep(post_x_treatment) varlabels(post_x_treatment "Post $\times$ Former peer gets mentioned")	///
		   mtitle("All periods" "+/-6 Window") 																///
		   varwidth(20) modelwidth(11) nonotes compress replace												///
		   scalars("mean \textit{Mean vic rates}" "pilotFE \textit{Pilot FE}" "eventFE \textit{Event FE}" "etFE \textit{Event time FE}")


***EXIT
est clear
*Column 1: all time periods
eststo m1: stcox post_x_treatment treated i.et, cl(id_squadron)
	*Add meab exit
	qui sum exit if !missing(id_squadron)
	estadd scalar mean = r(mean)
	*Add FEs
	estadd local treated "Y"
	estadd local etFE "Y"

*Column 2: +/- 6 window
preserve
	keep if event_time >= -6 & event_time <= 6
	eststo m2: stcox post_x_treatment treated i.et, cl(id_squadron)
		*Add meab exit
		qui sum exit if !missing(id_squadron)
		estadd scalar mean = r(mean)
		*Add FEs
		estadd local treated "Y"
		estadd local etFE "Y"
restore		   
esttab m1 m2 using "$gphpath/table3_exit.tex", 																///
		   eform(1 1) se star(* .1 ** .05 *** .01) b(%9.3f) booktabs 										///
		   keep(post_x_treatment) varlabels(post_x_treatment "Post $\times$ Former peer gets mentioned")	///
		   mtitle("All periods" "+/-6 Window") 																///
		   varwidth(20) modelwidth(11) nonotes compress replace												///
		   scalars("mean \textit{Mean exit rates}" "treated \textit{Treatment group FE}" "etFE \textit{Event time FE}")




************************************************************************************************************************
***										TABLE 4: DIFF-IN-DIFF BY QUALITY 											 ***
************************************************************************************************************************
use $datasetCEM.dta, clear
drop if exist_start == 0		//quality split sample
stset exp_scw, id(event_id) failure(exit==1)

***VICTORIES
est clear
*Column 1: bottom
eststo m1: xi: reghdfe vic post_x_treatment, cl(id_squadron) a(name_id event_id et), if top20 == 0
	*Add meab vic
	qui sum vic if top20 == 0 & !missing(id_squadron)
	estadd scalar mean = r(mean)
	*Controls and FE
	estadd local pilotFE "Y"
	estadd local eventFE "Y"
	estadd local etFE "Y"
	
*Column 2: top
eststo m2: xi: reghdfe vic post_x_treatment, cl(id_squadron) a(name_id event_id et), if top20 == 1
	*Add meab vic
	qui sum vic if top20 == 1 & !missing(id_squadron)
	estadd scalar mean = r(mean)
	*Controls and FE
	estadd local pilotFE "Y"
	estadd local eventFE "Y"
	estadd local etFE "Y"
		   
esttab m1 m2 using "$gphpath/table4_vic.tex", 										///
		   se r2 star(* .1 ** .05 *** .01) b(%9.3f) booktabs 						///
		   keep(post_x_treatment) mtitle("Bottom 80\%" "Top 20\%") 					///
		   varlabels(post_x_treatment "Post $\times$ Former peer gets mentioned")	///
		   varwidth(20) modelwidth(10) nonotes compress replace						///
		   scalars("mean \textit{Mean vic rates}" "pilotFE \textit{Pilot FE}" "eventFE \textit{Event FE}" "etFE \textit{Event time FE}")

		   
***EXIT	
est clear
*Column 1: bottom
eststo m1: xi: stcox  post_x_treatment treated i.et, cl(id_squadron), if top20 == 0
	*Add meab exit
	qui sum exit if top20 == 0 & !missing(id_squadron)
	estadd scalar mean = r(mean)
	*Controls and FE
	estadd local treated "Y"
	estadd local etFE "Y"

*Column 2: top
eststo m2: xi: stcox  post_x_treatment treated i.et, cl(id_squadron), if top20 == 1
	*Add meab exit
	qui sum exit if top20 == 1 & !missing(id_squadron)
	estadd scalar mean = r(mean)
	*Controls and FE
	estadd local treated "Y"
	estadd local etFE "Y"
	   
esttab m1 m2 using "$gphpath/table4_exit.tex",										///
		   se eform star(* .1 ** .05 *** .01) b(%9.3f) booktabs 					///
		   keep(post_x_treatment) mtitle("Bottom 80\%" "Top 20\%") 					///
		   varlabels(post_x_treatment "Post $\times$ Former peer gets mentioned")	///
		   varwidth(20) modelwidth(10) nonotes compress replace						///
		   scalars("mean \textit{Mean exit rates}" "treated \textit{Treatment group FE}" "etFE \textit{Event time FE}")
	

	
	
************************************************************************************************************************
***											 FIGURE 2: PILOTS EXAMPLE												 ***
************************************************************************************************************************
use $datasetCEM.dta, clear

**********************************************************************************************************
* Example pilots:																						 *
*  mentioned pilot: Franz Doerr (name_id==816) got mentioned in t==58									 *
*  --> past peer: Walter Schuck (name_id==4041)															 *
*  placebo-mentioned pilot (matched==1): Ernst Weismann (name_id==4783) got placebo-mentioned in t==36	 *
*  --> past peer: Franz-Josef Beerenbrock (name_id==208)												 *
**********************************************************************************************************
local treated_t = 58
local matched_t = 36
local treated_id = 816
local matched_id = 4783
local id_pptreated = 4041
local id_ppmatched = 208


*Create time relative to mention
gen time_since_mention = .
replace time_since_mention = t - `treated_t' if name_id == `treated_id' | name_id == `id_pptreated'
replace time_since_mention = t - `matched_t' if name_id == `matched_id' | name_id == `id_ppmatched'

*Only keep +/- 6 days
keep if time_since_mention >= -6 & time_since_mention <= 6

*Plot victories of past peer of mentioned and past peer of placebo-mentioned pilots
sort name_id t
twoway (connected vic time_since_mention if name_id == `id_pptreated', lcolor(black) lpattern(solid) lwidth(medthick) msymbol(none))		///
	   (connected vic time_since_mention if name_id == `id_ppmatched', lcolor(black*0.5) lpattern(longdash) lwidth(medthick) msymbol(diamond) mcolor(black*0.5) msize(medlarge))			///
	   , xline(-0.3) legend(order(1 "Former peer of mentioned pilot: Schuck" 2 "Former peer of placebo-mentioned pilot: Beerenbrock"))	///
		 ytitle("victories per month") xtitle("months since mention")					//x-axis: vic label was not adjustd when collapsing from daily to monthly
graph export "$gphpath/figure2.eps", replace



		
************************************************************************************************************************
***											FIGURE 4: DIFF-IN-DIFF EVENTPLOT										 ***
************************************************************************************************************************
use $datasetCEM.dta, clear
stset exp_scw, id(event_id) failure(exit==1)

***VICTORIES
est clear
eststo m0: xi: areg vic ib68.et##treated i.name_id, cl(id_squadron) a(event_id)

coefplot m0, keep(63.et#1.treated 64.et#1.treated 65.et#1.treated 66.et#1.treated   ///
				  67.et#1.treated 68.et#1.treated 69.et#1.treated 70.et#1.treated   ///
				  71.et#1.treated 72.et#1.treated 73.et#1.treated 74.et#1.treated 	///
				  75.et#1.treated) 													///
			 levels(90) cism vertical 	 											///
			 nokey xline(6.5, lcolor(red)) omitted baselevels 						///
			 yline(0, lpat(dash) lcolor(grey)) 										///	     	     
			 coeflabels(63.et#1.treated = "-6" 64.et#1.treated  = "-5" 				///
						65.et#1.treated = "-4" 66.et#1.treated  = "-3" 				/// 
						67.et#1.treated = "-2" 68.et#1.treated  = "-1" 				///
						69.et#1.treated =  "0" 70.et#1.treated  =  "1" 				/// 
						71.et#1.treated =  "2" 72.et#1.treated =  "3" 				/// 
						73.et#1.treated =  "4" 74.et#1.treated =  "5" 				/// 
						75.et#1.treated =  "6")										///
						xtitle("Months since mention")			

graph export "$gphpath/figure4_vic.eps", replace
	

***EXIT
eststo m0: xi: stcox ib68.et##treated, cl(id_squadron)

coefplot m0, keep(63.et#1.treated 64.et#1.treated 65.et#1.treated 66.et#1.treated  		///
				  67.et#1.treated 68.et#1.treated 69.et#1.treated 70.et#1.treated   	///
				  71.et#1.treated 72.et#1.treated 73.et#1.treated 74.et#1.treated 		///
				  75.et#1.treated) 														///
			 eform yscale(log) ylabel(0.25 0.5 1 2 4 8 16 32) levels(90) cism vertical  ///
			 nokey xline(6.5, lcolor(red)) omitted baselevels 							///
			 yline(1, lpat(dash) lcolor(grey)) 											///	     	     
			 coeflabels(63.et#1.treated = "-6" 64.et#1.treated  = "-5" 					///
						65.et#1.treated = "-4" 66.et#1.treated  = "-3" 					/// 
						67.et#1.treated = "-2" 68.et#1.treated  = "-1" 					///
						69.et#1.treated =  "0" 70.et#1.treated  =  "1" 					/// 
						71.et#1.treated =  "2" 72.et#1.treated =  "3" 					/// 
						73.et#1.treated =  "4" 74.et#1.treated =  "5" 					/// 
						75.et#1.treated =  "6")											///
						xtitle("Months since mention")

graph export "$gphpath/figure4_exit.eps", replace

	


************************************************************************************************************************
***											FIGURE 5: BIRTHPLACE DISTANCE				 							 ***
************************************************************************************************************************
use $datasetCEM.dta, clear

***Store histrogram data
preserve
	*Store histogram numbers
	twoway__histogram_gen birthdistance_window, gen(h x) width(20) start(0)
	keep if !missing(x)
	keep h x
	sum x if x > 600
	local x_above = r(min)
	replace x = `x_above' if x > `x_above'
	collapse (sum) h, by(x)
	
	sum x
	local x_min = r(min)	
	local x_max = r(max)
	replace x =`x_min'-40 if x == `x_min'
	replace x =`x_max'+40 if x == `x_max'
	*Make variable names compatible with margins data: xvar is _at1
	rename x _at1
	save temp/birthdist_hist, replace
restore

*Margins
preserve 

	*Adjust code to version of reghdfe
	reghdfe, compile // compiles lreghdfe.mlib if it does not exist or if it needs to be updated
	
	which_version reghdfe	//install which_version from SSC: ssc install which_version
	if s(version) == "5.7.3"{
		di "new"
		reghdfe vic c.birthdistance_window##post_x_treatment, cl(id_sq) a(name_id et) level(90) old	//no eventFE because collinear with birthdistance
	}
	else if s(version) == "3.2.9"{
		di "old"
		reghdfe vic c.birthdistance_window##post_x_treatment, cl(id_sq) a(name_id et) level(90)  	//no eventFE because collinear with birthdistance
	}
	
	local coef_control_dist0 = r(table)[1, 3]
	local lb_control_dist0    = r(table)[5, 3]
	local ub_control_dist0   = r(table)[6, 3]
	
	*Store margins
	margins, at(birthdistance_window=(0 100 200 300 400 500 600)) over(post_x_treatment) level(90)	///
			 saving(temp/birthdist_margins, replace)

restore

preserve
	use temp/birthdist_margins, clear
	replace _margin 	= `coef_control_dist0' if _at1==0 & _by1==0 & missing(_margin)
	replace _ci_lb		= `lb_control_dist0' if _at1==0 & _by1==0 & missing(_ci_lb)
	replace _ci_ub		= `ub_control_dist0' if _at1==0 & _by1==0 & missing(_ci_ub)
	save temp/birthdist_margins, replace
restore


*Combine margins and histogram data
use temp/birthdist_margins, clear
append using temp/birthdist_hist

*Histogram below
twoway (connected _margin _at1 if _by1==0)	///margins plot
	   (connected _margin _at1 if _by1==1)	///margins plot
	   (rcap _ci_lb _ci_ub _at1)		 	///confidence intervals
	   , ytitle("Victories") xtitle("average distance to pilots mentioned this month (in miles)") title("") ///
	     xscale(range(-50 660)) xlabel(0 100 200 300 400 500 600 650 ">600")				   				///
	     ylabel(0 "    0" 0.2 "    .2" 0.4 "    .4" 0.6 "    .6" 0.8 "    .8")				   				///
		 legend(order(2 "Former peer gets mentioned" 1 "Former peer gets placebo-mentioned") size(small))	///
		 saving(temp/marginsplot, replace) fysize(75)

twoway (bar h _at1, fintensity(25) lcolor(white) lwidth(vvvthin) barwidth(20))	///histogram (Note: lwidth(none) does not work -->tiny white line)
	   , ytitle("Density") xtitle("distance to peer (in miles)") title("")		///
	     xscale(range(0 650) off) xlabel(0 100 200 300 400 500 600 650 ">600")	///
		 yscale(rev)	///
	     saving(temp/hist, replace) fysize(25)

grc1leg temp/marginsplot.gph temp/hist.gph, cols(1) imargin(zero) name(combined_graph, replace)
graph display combined_graph, xsize(15) ysize(17)	
graph export "$gphpath/figure5.eps", replace
		
	
	
	
************************************************************************************************************************
***										FIGURE 6: SQUADRON PEERS, GROUP PEERS, BASE PEERS							 ***
************************************************************************************************************************

***VIC
est clear
*Squadron peers
use eventpilots_sqpeers, clear
eststo vic_sq: xi: reghdfe vic post_x_treatment, cl(id_squadron) a(name_id et)

*Group peers
use eventpilots_grpeers, clear
rename post_x_treatment post_x_grouptreatment	
eststo vic_gr: xi: reghdfe vic post_x_grouptreatment, cl(id_squadron) a(name_id et)

*Base peers
use eventpilots_bapeers, clear
rename post_x_treatment post_x_basetreatment
eststo vic_ba: xi: reghdfe vic post_x_basetreatment, cl(id_squadron) a(name_id et)

*Combined coefplot	   
coefplot vic_sq vic_gr vic_ba, keep(post_x_treatment post_x_basetreatment post_x_grouptreatment) 									///
		 coeflabels(post_x_treatment = "Squadron peers" post_x_basetreatment = "Base peers" post_x_grouptreatment = "Group peers")	/// 
		 cism levels(90) xscale(range(0)) xline(0) name(vic_graph, replace) 														///
		 nokey xlabel(#3 ,labsize(small))
		 
graph export "$gphpath/figure6_vic.eps", replace

	
***EXIT
est clear
*Squadron peers
use eventpilots_sqpeers, clear
stset exp_scw, id(event_id) failure(exit==1)
eststo exit_sq: xi: stcox post_x_treatment treated ib68.et, cl(id_squadron)

*Group peers
use eventpilots_grpeers, clear
rename post_x_treatment post_x_grouptreatment
stset exp_scw, id(event_id) failure(exit==1)
eststo exit_gr: xi: stcox post_x_grouptreatment treated ib68.et, cl(id_squadron)

*Base peers
use eventpilots_bapeers, clear
rename post_x_treatment post_x_basetreatment
stset exp_scw, id(event_id) failure(exit==1)
eststo exit_ba: xi: stcox post_x_basetreatment treated ib68.et, cl(id_squadron)

*Combined coefplot	   
coefplot exit_sq exit_gr exit_ba, keep(post_x_treatment post_x_basetreatment post_x_grouptreatment) 								///
		 coeflabels(post_x_treatment = "Squadron peers" post_x_basetreatment = "Base peers" post_x_grouptreatment = "Group peers")	/// 
		 cism levels(90) xline(1) name(exit_graph, replace) 																		///
		 eform xscale(log) nokey xlabel(1 2 4 ,labsize(small))
	 
graph export "$gphpath/figure6_exit.eps", replace
	
	
*Erase files
erase eventpilots_sqpeers.dta
erase eventpilots_grpeers.dta
erase eventpilots_bapeers.dta

	
************************************************************************************************************************
***									FIGURE 7: DIFF-IN-DIFF BY QUALITY, EVENT PLOT 									 ***
************************************************************************************************************************
est clear
use $datasetCEM.dta, clear
drop if exist_start == 0		//quality split sample

*Top
est clear
eststo m0: xi: areg vic ib68.et##treated i.name_id, cl(id_squadron) a(event_id), if top20 == 1 

coefplot m0, keep(63.et#1.treated 64.et#1.treated 65.et#1.treated 66.et#1.treated   ///
				  67.et#1.treated 68.et#1.treated 69.et#1.treated 70.et#1.treated   ///
				  71.et#1.treated 72.et#1.treated 73.et#1.treated 74.et#1.treated 	///
				  75.et#1.treated) 													///
			 levels(90) cism vertical  												///
			 nokey xline(6.5, lcolor(red)) omitted baselevels 						///
			 yline(0, lpat(dash) lcolor(grey)) 										///	     	     
			 coeflabels(63.et#1.treated = "-6" 64.et#1.treated  = "-5" 				///
						65.et#1.treated = "-4" 66.et#1.treated  = "-3" 				/// 
						67.et#1.treated = "-2" 68.et#1.treated  = "-1" 				///
						69.et#1.treated =  "0" 70.et#1.treated  =  "1" 				/// 
						71.et#1.treated =  "2" 72.et#1.treated =  "3" 				/// 
						73.et#1.treated =  "4" 74.et#1.treated =  "5" 				/// 
						75.et#1.treated =  "6")										///
						xtitle("Months since mention")

graph export "$gphpath/figure7_vic_top.eps", replace
		
*Bottom
est clear
eststo m0: xi: areg vic ib68.et##treated i.name_id, cl(id_squadron) a(event_id), if top20 == 0

coefplot m0, keep(63.et#1.treated 64.et#1.treated 65.et#1.treated 66.et#1.treated    				///
				  67.et#1.treated 68.et#1.treated 69.et#1.treated 70.et#1.treated    				///
				  71.et#1.treated 72.et#1.treated 73.et#1.treated 74.et#1.treated 					///
				  75.et#1.treated) 																	///
			 levels(90) cism vertical  																///
			 nokey  yline(-1, lcolor(gs14) lwidth(0.3))  xline(6.5, lcolor(red)) omitted baselevels ///
			 yline(0, lpat(dash) lcolor(grey))														///	     	     
			 coeflabels(63.et#1.treated = "-6" 64.et#1.treated  = "-5" 								///
						65.et#1.treated = "-4" 66.et#1.treated  = "-3" 								/// 
						67.et#1.treated = "-2" 68.et#1.treated  = "-1" 								///
						69.et#1.treated =  "0" 70.et#1.treated  =  "1" 								/// 
						71.et#1.treated =  "2" 72.et#1.treated =  "3" 								/// 
						73.et#1.treated =  "4" 74.et#1.treated =  "5" 								/// 
						75.et#1.treated =  "6")														///
						xtitle("Months since mention")

graph export "$gphpath/figure7_vic_bottom.eps", replace


***EXIT
*Top
est clear
eststo m0: xi: areg exit ib68.et##treated i.name_id, cl(id_squadron) a(event_id), if top20 ==1

coefplot m0, keep(63.et#1.treated 64.et#1.treated 65.et#1.treated 66.et#1.treated   ///
				  67.et#1.treated 68.et#1.treated 69.et#1.treated 70.et#1.treated   ///
				  71.et#1.treated 72.et#1.treated 73.et#1.treated 74.et#1.treated 	///
				  75.et#1.treated) 													///
			 levels(90) cism vertical  												///
			 nokey xline(6.5, lcolor(red)) omitted baselevels 						///
			 yline(0, lpat(dash) lcolor(grey))										///	     	     
			 coeflabels(63.et#1.treated = "-6" 64.et#1.treated  = "-5" 				///
						65.et#1.treated = "-4" 66.et#1.treated  = "-3" 				/// 
						67.et#1.treated = "-2" 68.et#1.treated  = "-1" 				///
						69.et#1.treated =  "0" 70.et#1.treated  =  "1" 				/// 
						71.et#1.treated =  "2" 72.et#1.treated =  "3" 				/// 
						73.et#1.treated =  "4" 74.et#1.treated =  "5" 				/// 
						75.et#1.treated =  "6")										///
						xtitle("Months since mention")

graph export "$gphpath/figure7_exit_top.eps", replace

*Bottom
est clear
eststo m0: xi: areg exit ib68.et##treated i.name_id, cl(id_squadron) a(event_id), if top20 == 0

coefplot m0, keep(63.et#1.treated 64.et#1.treated 65.et#1.treated 66.et#1.treated   ///
				  67.et#1.treated 68.et#1.treated 69.et#1.treated 70.et#1.treated   ///
				  71.et#1.treated 72.et#1.treated 73.et#1.treated 74.et#1.treated   ///
				  75.et#1.treated) 													///
			 levels(90) cism vertical  												///
			 nokey xline(6.5, lcolor(red)) omitted baselevels 						///
			 yline(0, lpat(dash) lcolor(grey)) 										///	     	     
			 coeflabels(63.et#1.treated = "-6" 64.et#1.treated  = "-5" 				///
						65.et#1.treated = "-4" 66.et#1.treated  = "-3" 				/// 
						67.et#1.treated = "-2" 68.et#1.treated  = "-1" 				///
						69.et#1.treated =  "0" 70.et#1.treated  =  "1" 				/// 
						71.et#1.treated =  "2" 72.et#1.treated =  "3" 				/// 
						73.et#1.treated =  "4" 74.et#1.treated =  "5" 				/// 
						75.et#1.treated =  "6")										///
						xtitle("Months since mention")

graph export "$gphpath/figure7_exit_bottom.eps", replace




************************************************************************************************************************
***									FIGURE 9: ALTERNATIVE OUTCOME ACTIVE DAYS			 							 ***
************************************************************************************************************************
use $datasetCEM.dta, clear

est clear
eststo m0: xi: areg vicdays_per_month ib68.et##treated i.name_id, cl(id_squadron) a(event_id)

*create the figure
coefplot m0, keep(63.et#1.treated 64.et#1.treated 65.et#1.treated 66.et#1.treated   ///
				  67.et#1.treated 68.et#1.treated 69.et#1.treated 70.et#1.treated   ///
				  71.et#1.treated 72.et#1.treated 73.et#1.treated 74.et#1.treated 	///
				  75.et#1.treated) 													///
			 levels(90) cism vertical  												///
			 nokey xline(6.5, lcolor(red)) omitted baselevels 						///
			 yline(0, lpat(dash) lcolor(grey)) 										///	     	  	   
			 coeflabels(63.et#1.treated = "-6" 64.et#1.treated  = "-5" 				///
						65.et#1.treated = "-4" 66.et#1.treated  = "-3" 				/// 
						67.et#1.treated = "-2" 68.et#1.treated  = "-1" 				///
						69.et#1.treated =  "0" 70.et#1.treated  =  "1" 				/// 
						71.et#1.treated =  "2" 72.et#1.treated =  "3" 				/// 
						73.et#1.treated =  "4" 74.et#1.treated =  "5" 				/// 
						75.et#1.treated =  "6")										///
						xtitle("Months since mention")

graph export "$gphpath/figure9.eps", replace


		   
		   
************************************************************************************************************************
***								FIGURE 10: ALTERNATIVE OUTCOME EXITS-ACTIVE-DAYS-RATIO			 					 ***
************************************************************************************************************************
use $datasetCEM.dta, clear

est clear
eststo m0: xi: areg exit_vicdays_ratio ib68.et##treated i.name_id, cl(id_squadron) a(event_id)

*create the figure
coefplot m0, keep(63.et#1.treated 64.et#1.treated 65.et#1.treated 66.et#1.treated   ///
				  67.et#1.treated 68.et#1.treated 69.et#1.treated 70.et#1.treated   ///
				  71.et#1.treated 72.et#1.treated 73.et#1.treated 74.et#1.treated 	///
				  75.et#1.treated)													///
			 levels(90) cism vertical  												///
			 nokey xline(6.5, lcolor(red)) omitted baselevels 						///
			 yline(0, lpat(dash) lcolor(grey)) 										///	     	     
			 coeflabels(63.et#1.treated = "-6" 64.et#1.treated  = "-5" 				///
						65.et#1.treated = "-4" 66.et#1.treated  = "-3" 				/// 
						67.et#1.treated = "-2" 68.et#1.treated  = "-1" 				///
						69.et#1.treated =  "0" 70.et#1.treated  =  "1" 				/// 
						71.et#1.treated =  "2" 72.et#1.treated =  "3" 				/// 
						73.et#1.treated =  "4" 74.et#1.treated =  "5" 				/// 
						75.et#1.treated =  "6")										///
						xtitle("Months since mention")

graph export "$gphpath/figure10.eps", replace


	

************************************************************************************************************************
***												FIGURE 13: BASE DISTANCES											 ***
************************************************************************************************************************
est clear
use $datasetCEM.dta, clear
stset exp_scw, id(event_id) failure(exit==1)

***VICTORIES
est clear
eststo baseline: xi: reghdfe vic post_x_treatment, cl(id_squadron) a(name_id et event_id)
eststo m1: xi: reghdfe vic post_x_treatment, cl(id_squadron) a(name_id et event_id), if (distancementioned_window >=250  & distancementioned_window !=. & treated == 1) | treated == 0
eststo m2: xi: reghdfe vic post_x_treatment, cl(id_squadron) a(name_id et event_id), if (distancementioned_window >=500  & distancementioned_window !=. & treated == 1) | treated == 0
eststo m3: xi: reghdfe vic post_x_treatment, cl(id_squadron) a(name_id et event_id), if (distancementioned_window >=750  & distancementioned_window !=. & treated == 1) | treated == 0
eststo m4: xi: reghdfe vic post_x_treatment, cl(id_squadron) a(name_id et event_id), if (distancementioned_window >=1000 & distancementioned_window !=. & treated == 1) | treated == 0
	   
coefplot baseline m1 m2 m3 m4, keep(post_x_treatment) cism levels(90) 						///
		 xline(0) name(vic_graph, replace) aseq swapnames nokey  							///
		 coeflabels(m1 = "250 miles" m2 = "500 miles" m3 = "750 miles" m4= "1000 miles")	///
		 xlabel(#3 ,labsize(small))

graph export "$gphpath/figure13_vic.eps", replace


***EXITS
est clear
eststo baseline: xi: stcox  post_x_treatment treated ib68.et, cl(id_squadron)
eststo m1: xi: stcox  post_x_treatment treated ib68.et, cl(id_squadron), if (distancementioned_window >=250  & distancementioned_window !=. & treated == 1) | treated == 0
eststo m2: xi: stcox  post_x_treatment treated ib68.et, cl(id_squadron), if (distancementioned_window >=500  & distancementioned_window !=. & treated == 1) | treated == 0
eststo m3: xi: stcox  post_x_treatment treated ib68.et, cl(id_squadron), if (distancementioned_window >=750  & distancementioned_window !=. & treated == 1) | treated == 0
eststo m4: xi: stcox  post_x_treatment treated ib68.et, cl(id_squadron), if (distancementioned_window >=1000 & distancementioned_window !=. & treated == 1) | treated == 0

coefplot baseline m1 m2 m3 m4, keep(post_x_treatment) cism levels(90) eform xscale(log)  	///
		 xline(1) name(vic_graph, replace) aseq swapnames nokey  							///
		 coeflabels(m1 = "250 miles" m2 = "500 miles" m3 = "750 miles" m4= "1000 miles")	///
		 xlabel(1 2 4 8 16 32 64 128) xlabel( ,labsize(small))
		 
graph export "$gphpath/figure13_exit.eps", replace
			   
	
	
	
************************************************************************************************************************
***												TABLES A5: EXIT WITH OLS											 ***
************************************************************************************************************************
use $datasetCEM.dta, clear

est clear
*Column 1: all periods
eststo m1: xi: reghdfe exit post_x_treatment treated, cl(id_squadron) a(et)
	*Add mean exit
	qui sum exit if !missing(id_squadron)
	estadd scalar mean = r(mean)
	*Add FEs
	estadd local treated "Y"
	estadd local etFE "Y"

*Column 2: +/-6 window
keep if event_time >= -6 & event_time <= 6

eststo m2: xi: reghdfe exit post_x_treatment treated, cl(id_squadron) a(et)
	*Add mean exit
	qui sum exit if !missing(id_squadron)
	estadd scalar mean = r(mean)
	*Add FEs
	estadd local treated "Y"
	estadd local etFE "Y"
		   
esttab m1 m2 using "$gphpath/tableA5.tex", 																										///
		   se r2 star(* .1 ** .05 *** .01) b(%9.3f) booktabs 																					///
		   keep(post_x_treatment) varlabels(post_x_treatment "Post $\times$ Former peer gets mentioned") mtitle("All periods" "+/-6 Window")	///
		   varwidth(20) modelwidth(11) nonotes compress replace																					///
		   scalars("mean \textit{Mean exit rates}" "treated \textit{Treatment group FE}" "etFE \textit{Event time FE}")
		
	


************************************************************************************************************************
***											TABLE A6: MENTIONED PILOT CLUSTER										 ***
************************************************************************************************************************
use $datasetCEM.dta, clear
stset exp_scw, id(event_id) failure(exit==1)
drop if missing(id_squadron)	//same sample as for main table

***VICTORIES
est clear
preserve
	*Column 1: all time periods
	eststo m1: xi: reghdfe vic post_x_treatment, cl(peer_cluster) a(name_id event_id et)
		*Add meab vic
		qui sum vic
		estadd scalar mean = r(mean)
		*Add FEs
		estadd local pilotFE "Y"
		estadd local eventFE "Y"
		estadd local etFE "Y"

	*Column 2: +/-6 time window
	keep if event_time >= -6 & event_time <= 6
		eststo m3: xi: reghdfe vic post_x_treatment, cl(peer_cluster) a(name_id event_id et)
		*Add meab vic
		qui sum vic
		estadd scalar mean = r(mean)
		*Add FEs
		estadd local pilotFE "Y"
		estadd local eventFE "Y"
		estadd local etFE "Y"
restore
	 
esttab m1 m3 using "$gphpath/tableA6_vic.tex", 		 																					///
		   se r2 star(* .1 ** .05 *** .01) b(%9.3f) booktabs																			///
		   keep(post_x_treatment) varlabels(post_x_treatment "Post x Former peer gets mentioned") mtitle("All periods" "+/-6 Window")	///
		   varwidth(20) modelwidth(11) nonotes compress replace																			///
		   scalars("mean \textit{Mean vic rates}" "pilotFE \textit{Pilot FE}" "eventFE \textit{Event FE}" "etFE \textit{Event time FE}")

		  	   
***EXIT
est clear
preserve
	*Column 1: All periods
	eststo m1: stcox post_x_treatment treated i.et, cl(peer_cluster)
		*Add meab exit
		qui sum exit
		estadd scalar mean = r(mean)
		*Add FEs
		estadd local treated "Y"
		estadd local etFE "Y"


		*Column 2: +/-6 time window
	keep if event_time >= -6 & event_time <= 6
	eststo m2: stcox post_x_treatment treated i.et, cl(peer_cluster)
		*Add meab exit
		qui sum exit
		estadd scalar mean = r(mean)
		*Add FEs
		estadd local treated "Y"
		estadd local etFE "Y"
restore
		   
esttab m1 m2 using "$gphpath/tableA6_exit.tex", 																								///
		   eform(1 1) se star(* .1 ** .05 *** .01) b(%9.3f) booktabs 																			///
		   keep(post_x_treatment) varlabels(post_x_treatment "Post $\times$ Former peer gets mentioned") mtitle("All periods" "+/-6 Window")	///
		   varwidth(20) modelwidth(11) nonotes compress replace																					///
		   scalars("mean \textit{Mean exit rates}" "treated \textit{Treatment group FE}" "etFE \textit{Event time FE}")
	
		
		

************************************************************************************************************************
***									TABLES A7: DIFF-IN-DIFF VICTORIES, BALANCED PANEL								 ***
************************************************************************************************************************
use $datasetCEM.dta, clear

est clear
*Column 1: exist in event_time == -6
drop if exist_start == 0
eststo m1: xi: reghdfe vic post_x_treatment, cl(id_squadron) a(name_id event_id et)
	*Add meab vic
	qui sum vic if !missing(id_squadron)
	estadd scalar mean = r(mean)
	*Add FEs
	estadd local pilotFE "Y"
	estadd local eventFE "Y"
	estadd local etFE "Y"

*Column 2: +/-6 window
keep if event_time >= -6 & event_time <= 6
eststo m2: xi: reghdfe vic post_x_treatment, cl(id_squadron) a(name_id event_id et)
	*Add meab vic
	qui sum vic if !missing(id_squadron)
	estadd scalar mean = r(mean)
	*Add FEs
	estadd local pilotFE "Y"
	estadd local eventFE "Y"
	estadd local etFE "Y"

*Column 3: only keep events where pilots are still alive in t+6 (balanced sample)
gen exist6plus_h = 0
replace exist6plus_h = 1 if event_time == +6
bysort event_num treated: egen exist_end = max(exist6plus_h)
drop if exist_end == 0
eststo m3: xi: reghdfe vic post_x_treatment, cl(id_squadron) a(name_id event_id et)
	*Add meab vic
	qui sum vic if !missing(id_squadron)
	estadd scalar mean = r(mean)
	*Add FEs
	estadd local pilotFE "Y"
	estadd local eventFE "Y"
	estadd local etFE "Y"
		   
esttab m1 m2 m3 using "$gphpath/tableA7.tex", 																///
		   se r2 star(* .1 ** .05 *** .01) b(%9.3f) booktabs												///
		   keep(post_x_treatment) varlabels(post_x_treatment "Post $\times$ Former peer gets mentioned")	///
		   mtitle("Exist in t-6"  "Exist in t-6, +/-6 Window" "+/-6 Window, balanced") 						///
		   varwidth(20) modelwidth(11) nonotes compress replace												///
		   scalars("mean \textit{Mean vic rates}" "pilotFE \textit{Pilot FE}" "eventFE \textit{Event FE}" "etFE \textit{Event time FE}")
	



************************************************************************************************************************
***							TABLE A8: DIFF-IN-DIFF BY QUALITY, MENTIONED PEER CLUSTER 								 ***
************************************************************************************************************************
use $datasetCEM.dta, clear
stset exp_scw, id(event_id) failure(exit==1)
drop if exist_start == 0		//quality split sample
drop if missing(id_squadron)	//same sample as for main table


***VICTORIES
est clear
*Column 1: bottom
eststo m1: xi: reghdfe vic post_x_treatment, cl(peer_cluster) a(name_id event_id et), if top20 == 0
	*Add meab vic
	qui sum vic if top20 == 0
	estadd scalar mean = r(mean)
	*Controls and FE
	estadd local pilotFE "Y"
	estadd local eventFE "Y"
	estadd local etFE "Y"
	
*Column 2: top
eststo m2: xi: reghdfe vic post_x_treatment, cl(peer_cluster) a(name_id event_id et), if top20 == 1
	*Add meab vic
	qui sum vic if top20 == 1
	estadd scalar mean = r(mean)
	*Controls and FE
	estadd local pilotFE "Y"
	estadd local eventFE "Y"
	estadd local etFE "Y"

	   
esttab m1 m2 using "$gphpath/tableA8_vic.tex", 										///
		   se r2 star(* .1 ** .05 *** .01) b(%9.3f) booktabs 						///
		   keep(post_x_treatment) mtitle("Bottom 80\%" "Top 20\%") 					///
		   varlabels(post_x_treatment "Post $\times$ Former peer gets mentioned")	///
		   varwidth(20) modelwidth(10) nonotes compress replace						///
		   scalars("mean \textit{Mean vic rates}" "pilotFE \textit{Pilot FE}" "eventFE \textit{Event FE}" "etFE \textit{Event time FE}")

	

***EXIT
est clear
*Column 1: bottom
eststo m1: xi: stcox  post_x_treatment treated i.et, cl(peer_cluster), if top20 == 0
	*Add meab exit
	qui sum exit if top20 == 0
	estadd scalar mean = r(mean)
	*Controls and FE
	estadd local treated "Y"
	estadd local etFE "Y"
*Column 2: top
eststo m2: xi: stcox  post_x_treatment treated i.et, cl(peer_cluster), if top20 == 1
	*Add meab exit
	qui sum exit if top20 == 1
	estadd scalar mean = r(mean)
	*Controls and FE
	estadd local treated "Y"
	estadd local etFE "Y"

		   
esttab m1 m2 using "$gphpath/tableA8_exit.tex", 									///
		   se eform star(* .1 ** .05 *** .01) b(%9.3f) booktabs 					///
		   keep(post_x_treatment) mtitle("Bottom 80\%" "Top 20\%") 					///
		   varlabels(post_x_treatment "Post $\times$ Former peer gets mentioned")	///
		   varwidth(20) modelwidth(10) nonotes compress replace						///
		   scalars("mean \textit{Mean exit rates}" "treated \textit{Treatment group FE}" "etFE \textit{Event time FE}")
	

	
	
************************************************************************************************************************
***										TABLE A9: ALTERNATIVE QUALITY SPLITS		 								 ***
************************************************************************************************************************
use $datasetCEM.dta, clear
stset exp_scw, id(event_id) failure(exit==1)
drop if exist_start == 0		//quality split sample

est clear
***SPLIT 90-10	
*Victories
eststo q90vicbottom: xi: reghdfe vic post_x_treatment, cl(id_squadron) a(name_id event_id et), if top10 == 0
	*Add meab vic
	qui sum vic if top10 == 0 & !missing(id_squadron)
	estadd scalar mean = r(mean)
	*Controls and FE
	estadd local pilotFE "Y"
	estadd local eventFE "Y"
	estadd local etFE "Y"

eststo q90victop: xi: reghdfe vic post_x_treatment, cl(id_squadron) a(name_id event_id et), if top10 == 1
	*Add meab vic
	qui sum vic if top10 == 1 & !missing(id_squadron)
	estadd scalar mean = r(mean)
	*Controls and FE
	estadd local pilotFE "Y"
	estadd local eventFE "Y"
	estadd local etFE "Y"

*Exit
eststo q90exitbottom: xi: stcox  post_x_treatment treated i.et, cl(id_squadron), if top10 == 0
	*Add meab exit
	qui sum exit if top10 == 0 & !missing(id_squadron)
	estadd scalar mean = r(mean)
	*Controls and FE
	estadd local treated "Y"
	estadd local etFE "Y"
eststo q90exittop: xi: stcox  post_x_treatment treated i.et, cl(id_squadron), if top10 == 1
	*Add meab exit
	qui sum exit if top10 == 1 & !missing(id_squadron)
	estadd scalar mean = r(mean)
	*Controls and FE
	estadd local treated "Y"
	estadd local etFE "Y"


***SPLIT 70-30
*Victories
eststo q70vicbottom: xi: reghdfe vic post_x_treatment, cl(id_squadron) a(name_id event_id et), if top30 == 0
	*Add meab vic
	qui sum vic if top30 == 0 & !missing(id_squadron)
	estadd scalar mean = r(mean)
	*Controls and FE
	estadd local pilotFE "Y"
	estadd local eventFE "Y"
	estadd local etFE "Y"

eststo q70victop: xi: reghdfe vic post_x_treatment, cl(id_squadron) a(name_id event_id et), if top30 == 1
	*Add meab vic
	qui sum vic if top30 == 1 & !missing(id_squadron)
	estadd scalar mean = r(mean)
	*Controls and FE
	estadd local pilotFE "Y"
	estadd local eventFE "Y"
	estadd local etFE "Y"

*Exit
eststo q70exitbottom: xi: stcox  post_x_treatment treated i.et, cl(id_squadron), if top30 == 0
	*Add meab exit
	qui sum exit if top30 == 0 & !missing(id_squadron)
	estadd scalar mean = r(mean)
	*Controls and FE
	estadd local treated "Y"
	estadd local etFE "Y"
eststo q70exittop: xi: stcox  post_x_treatment treated i.et, cl(id_squadron), if top30 == 1
	*Add meab exit
	qui sum exit if top30 == 1 & !missing(id_squadron)
	estadd scalar mean = r(mean)
	*Controls and FE
	estadd local treated "Y"
	estadd local etFE "Y"
		

***Create tables
*Table vic   
esttab q90vicbottom q90victop q70vicbottom q70victop using "$gphpath/tableA9_vic.tex", 		///
		   se r2 star(* .1 ** .05 *** .01) b(%9.3f) booktabs 								///
		   keep(post_x_treatment) mtitle("Bottom 90\%" "Top 10\%" "Bottom 70\%" "Top 30\%") ///
		   varlabels(post_x_treatment "Post $\times$ Former peer gets mentioned")			///
		   varwidth(20) modelwidth(10) nonotes compress replace								///
		   scalars("mean \textit{Mean vic rates}" "pilotFE \textit{Pilot FE}" "eventFE \textit{Event FE}" "etFE \textit{Event time FE}")


*Table exit
esttab q90exitbottom q90exittop q70exitbottom q70exittop using "$gphpath/tableA9_exit.tex", ///
		   se eform star(* .1 ** .05 *** .01) b(%9.3f) booktabs 							///
		   keep(post_x_treatment) mtitle("Bottom 90\%" "Top 10\%" "Bottom 70\%" "Top 30\%") ///
		   varlabels(post_x_treatment "Post $\times$ Former peer gets mentioned")			///
		   varwidth(20) modelwidth(10) nonotes compress replace								///
		   scalars("mean \textit{Mean exit rates}" "treated \textit{Treatment group FE}" "etFE \textit{Event time FE}")
	
	
	
	
************************************************************************************************************************
***									FIGURE A3: DIFF-IN-DIFF EXIT WITH OLS, EVENT PLOT								 ***
************************************************************************************************************************
use $datasetCEM.dta, clear

est clear
eststo m0: xi: areg exit ib68.et##treated i.name_id, cl(id_squadron) a(event_id)
	
*create the figure
coefplot m0, keep(63.et#1.treated 64.et#1.treated 65.et#1.treated 66.et#1.treated   ///
				  67.et#1.treated 68.et#1.treated 69.et#1.treated 70.et#1.treated   ///
				  71.et#1.treated 72.et#1.treated 73.et#1.treated 74.et#1.treated 	///
				  75.et#1.treated)													///
			 levels(90) cism vertical 												///
			 nokey xline(6.5, lcolor(red)) omitted baselevels						///
			 yline(0, lpat(dash) lcolor(grey)) 										///	     	     
			 coeflabels(63.et#1.treated = "-6" 64.et#1.treated  = "-5" 				///
						65.et#1.treated = "-4" 66.et#1.treated  = "-3"				/// 
						67.et#1.treated = "-2" 68.et#1.treated  = "-1" 				///
						69.et#1.treated =  "0" 70.et#1.treated  =  "1" 				/// 
						71.et#1.treated =  "2" 72.et#1.treated =  "3" 				/// 
						73.et#1.treated =  "4" 74.et#1.treated =  "5" 				/// 
						75.et#1.treated =  "6")										///
						xtitle("Months since mention")

graph export "$gphpath/figureA3.eps", replace


	
	
************************************************************************************************************************
***										FIGURE A4: DIFF-IN-DIFF, MENTIONED PEER CLUSTERING							 ***
************************************************************************************************************************
use $datasetCEM.dta, clear
stset exp_scw, id(event_id) failure(exit==1)

***VICTORIES
est clear
eststo m0: xi: areg vic ib68.et##treated i.name_id, cl(peer_cluster) a(event_id)

*create the figure
coefplot m0, keep(63.et#1.treated 64.et#1.treated 65.et#1.treated 66.et#1.treated   ///
				  67.et#1.treated 68.et#1.treated 69.et#1.treated 70.et#1.treated   ///
				  71.et#1.treated 72.et#1.treated 73.et#1.treated 74.et#1.treated 	///
				  75.et#1.treated) 													///
			 levels(90) cism vertical 												///
			 nokey xline(6.5, lcolor(red)) omitted baselevels 						///
			 yline(0, lpat(dash) lcolor(grey)) ylabels(-0.5(0.5)1)					///	     	     
			 coeflabels(63.et#1.treated = "-6" 64.et#1.treated  = "-5" 				///
						65.et#1.treated = "-4" 66.et#1.treated  = "-3" 				/// 
						67.et#1.treated = "-2" 68.et#1.treated  = "-1" 				///
						69.et#1.treated =  "0" 70.et#1.treated  =  "1" 				/// 
						71.et#1.treated =  "2" 72.et#1.treated =  "3" 				/// 
						73.et#1.treated =  "4" 74.et#1.treated =  "5" 				/// 
						75.et#1.treated =  "6")										///
						xtitle("Months since mention")

graph export "$gphpath/figureA4_vic.eps", replace


***EXIT
est clear
eststo m0: xi: stcox ib68.et##treated, cl(peer_cluster)

*create the figure
coefplot m0, keep(63.et#1.treated 64.et#1.treated 65.et#1.treated 66.et#1.treated   	///
				  67.et#1.treated 68.et#1.treated 69.et#1.treated 70.et#1.treated   	///
				  71.et#1.treated 72.et#1.treated 73.et#1.treated 74.et#1.treated		///
				  75.et#1.treated) 														///
			 eform yscale(log) ylabel(0.25 0.5 1 2 4 8 16 32) levels(90) cism vertical  ///
			 nokey xline(6.5, lcolor(red)) omitted baselevels 							///
			 yline(1, lpat(dash) lcolor(grey)) 											///	     	     
			 coeflabels(63.et#1.treated = "-6" 64.et#1.treated  = "-5" 					///
						65.et#1.treated = "-4" 66.et#1.treated  = "-3" 					/// 
						67.et#1.treated = "-2" 68.et#1.treated  = "-1" 					///
						69.et#1.treated =  "0" 70.et#1.treated  =  "1" 					/// 
						71.et#1.treated =  "2" 72.et#1.treated =  "3" 					/// 
						73.et#1.treated =  "4" 74.et#1.treated =  "5" 					/// 
						75.et#1.treated =  "6")											///
						xtitle("Months since mention")

graph export "$gphpath/figureA4_exit.eps", replace


	

************************************************************************************************************************
***									FIGURE A5: DIFF-IN-DIFF BY QUALITY, EXIT OLS	 								 ***
************************************************************************************************************************
use $datasetCEM.dta, clear
drop if exist_start == 0		//quality split sample
stset exp_scw, id(event_id) failure(exit==1)

*Top
est clear
eststo m0: xi: stcox ib68.et##treated, cl(id_squadron), if top20 ==1

coefplot m0, keep(				  64.et#1.treated				  66.et#1.treated   /// do not show coefficients for time periods with zero exits for treated or control
				  67.et#1.treated 68.et#1.treated 69.et#1.treated 70.et#1.treated   ///
				  71.et#1.treated 72.et#1.treated 73.et#1.treated 74.et#1.treated	///
				  75.et#1.treated)													///
			 eform yscale(log) ylabels(0.015625 0.03125 0.0625 0.125 0.25 0.5 1 2 4 8 16 32 64 128) levels(90) cism vertical ///
			 nokey xline(6.5, lcolor(red)) omitted baselevels 						///
			 yline(1, lpat(dash) lcolor(grey)) 										///	     	     
			 norescaling  															///
			 order(. 64.et#1.treated . 66.et#1.treated								///
				   67.et#1.treated 68.et#1.treated 69.et#1.treated 70.et#1.treated	///
				   71.et#1.treated 72.et#1.treated 73.et#1.treated 74.et#1.treated 	/// 
				   75.et#1.treated)													///
			 xlabel(1 "-6" 2 "-5" 3 "-4" 4 "-3" 5 "-2" 6 "-1" 7 "0" 8 "1" 9 "2" 10 "3" 11 "4" 12 "5" 13 "6")		///
						xtitle("Months since mention")
				  				
graph export "$gphpath/figureA5_top.eps", replace


*Bottom
est clear
eststo m0: xi: stcox ib68.et##treated, cl(id_squadron), if top20 ==0

coefplot m0, keep(63.et#1.treated 64.et#1.treated 65.et#1.treated 66.et#1.treated    	///
				  67.et#1.treated 68.et#1.treated 69.et#1.treated 70.et#1.treated   	///
				  71.et#1.treated 72.et#1.treated 73.et#1.treated 74.et#1.treated 		///
				  75.et#1.treated) 														///
			 eform yscale(log) ylabels(0.25 0.5 1 2 4 8 16 32) levels(90) cism vertical ///
			 nokey xline(6.5, lcolor(red)) omitted baselevels 							///
			 yline(1, lpat(dash) lcolor(grey)) 											///	     	     
			 coeflabels(63.et#1.treated = "-6" 64.et#1.treated  = "-5" 					///
						65.et#1.treated = "-4" 66.et#1.treated  = "-3" 					/// 
						67.et#1.treated = "-2" 68.et#1.treated  = "-1" 					///
						69.et#1.treated =  "0" 70.et#1.treated  =  "1" 					/// 
						71.et#1.treated =  "2" 72.et#1.treated =  "3" 					/// 
						73.et#1.treated =  "4" 74.et#1.treated =  "5" 					/// 
						75.et#1.treated =  "6")											///
						xtitle("Months since mention")

graph export "$gphpath/figureA5_bottom.eps", replace
	


	
************************************************************************************************************************
***								FIGURE A6: DIFF-IN-DIFF BY QUALITY, MENTIONED PEER CLUSTERING						 ***
************************************************************************************************************************
use $datasetCEM.dta, clear
drop if missing(id_squadron)	//same sample as for main table
drop if exist_start == 0		//quality split sample


***VICTORIES TOP	
est clear
eststo m0: xi: areg vic ib68.et##treated i.name_id, cl(peer_cluster) a(event_id), if top20 == 1 

*create the figure
coefplot m0, keep(63.et#1.treated 64.et#1.treated 65.et#1.treated 66.et#1.treated   ///
				  67.et#1.treated 68.et#1.treated 69.et#1.treated 70.et#1.treated   ///
				  71.et#1.treated 72.et#1.treated 73.et#1.treated 74.et#1.treated 	///
				  75.et#1.treated) 													///
			 levels(90) cism vertical  												///
			 nokey xline(6.5, lcolor(red)) omitted baselevels 						///
			 yline(0, lpat(dash) lcolor(grey)) 										///	     	     
			 coeflabels(63.et#1.treated = "-6" 64.et#1.treated  = "-5" 				///
						65.et#1.treated = "-4" 66.et#1.treated  = "-3" 				/// 
						67.et#1.treated = "-2" 68.et#1.treated  = "-1" 				///
						69.et#1.treated =  "0" 70.et#1.treated  =  "1" 				/// 
						71.et#1.treated =  "2" 72.et#1.treated =  "3" 				/// 
						73.et#1.treated =  "4" 74.et#1.treated =  "5" 				/// 
						75.et#1.treated =  "6")										///
						xtitle("Months since mention")

graph export "$gphpath/figureA6_vic_top.eps", replace


***VICTORIES BOTTOM
est clear
eststo m0: xi: areg vic ib68.et##treated i.name_id, cl(peer_cluster) a(event_id), if top20 == 0

*create the figure
coefplot m0, keep(63.et#1.treated 64.et#1.treated 65.et#1.treated 66.et#1.treated    				///
				  67.et#1.treated 68.et#1.treated 69.et#1.treated 70.et#1.treated    				///
				  71.et#1.treated 72.et#1.treated 73.et#1.treated 74.et#1.treated 					///
				  75.et#1.treated) 																	///
			 levels(90) cism vertical  																///
			 nokey  yline(-1, lcolor(gs14) lwidth(0.3))  xline(6.5, lcolor(red)) omitted baselevels ///
			 yline(0, lpat(dash) lcolor(grey)) 														///	     	     
			 coeflabels(63.et#1.treated = "-6" 64.et#1.treated  = "-5" 								///
						65.et#1.treated = "-4" 66.et#1.treated  = "-3" 								/// 
						67.et#1.treated = "-2" 68.et#1.treated  = "-1" 								///
						69.et#1.treated =  "0" 70.et#1.treated  =  "1" 								/// 
						71.et#1.treated =  "2" 72.et#1.treated =  "3" 								/// 
						73.et#1.treated =  "4" 74.et#1.treated =  "5" 								/// 
						75.et#1.treated =  "6")														///
						xtitle("Months since mention")

graph export "$gphpath/figureA6_vic_bottom.eps", replace


***EXIT TOP
est clear
eststo m0: xi: areg exit ib68.et##treated i.name_id, cl(peer_cluster) a(event_id), if top20 ==1

*create the figure
coefplot m0, keep(63.et#1.treated 64.et#1.treated 65.et#1.treated 66.et#1.treated   ///
				  67.et#1.treated 68.et#1.treated 69.et#1.treated 70.et#1.treated   ///
				  71.et#1.treated 72.et#1.treated 73.et#1.treated 74.et#1.treated 	///
				  75.et#1.treated) 													///
			 levels(90) cism vertical  												///
			 nokey xline(6.5, lcolor(red)) omitted baselevels 						///
			 yline(0, lpat(dash) lcolor(grey)) 										///	     	     
			 coeflabels(63.et#1.treated = "-6" 64.et#1.treated  = "-5" 				///
						65.et#1.treated = "-4" 66.et#1.treated  = "-3" 				/// 
						67.et#1.treated = "-2" 68.et#1.treated  = "-1" 				///
						69.et#1.treated =  "0" 70.et#1.treated  =  "1" 				/// 
						71.et#1.treated =  "2" 72.et#1.treated =  "3" 				/// 
						73.et#1.treated =  "4" 74.et#1.treated =  "5" 				/// 
						75.et#1.treated =  "6")										///
						xtitle("Months since mention")

graph export "$gphpath/figureA6_exit_top.eps", replace	


***EXIT BOTTOM
est clear
eststo m0: xi: areg exit ib68.et##treated i.name_id, cl(peer_cluster) a(event_id), if top20 == 0

*create the figure
coefplot m0, keep(63.et#1.treated 64.et#1.treated 65.et#1.treated 66.et#1.treated   ///
				  67.et#1.treated 68.et#1.treated 69.et#1.treated 70.et#1.treated   ///
				  71.et#1.treated 72.et#1.treated 73.et#1.treated 74.et#1.treated   ///
				  75.et#1.treated) 													///
			 levels(90) cism vertical  												///
			 nokey xline(6.5, lcolor(red)) omitted baselevels 						///
			 yline(0, lpat(dash) lcolor(grey)) 										///	     	     
			 coeflabels(63.et#1.treated = "-6" 64.et#1.treated  = "-5" 				///
						65.et#1.treated = "-4" 66.et#1.treated  = "-3" 				/// 
						67.et#1.treated = "-2" 68.et#1.treated  = "-1" 				///
						69.et#1.treated =  "0" 70.et#1.treated  =  "1" 				/// 
						71.et#1.treated =  "2" 72.et#1.treated =  "3" 				/// 
						73.et#1.treated =  "4" 74.et#1.treated =  "5" 				/// 
						75.et#1.treated =  "6")										///
						xtitle("Months since mention")

graph export "$gphpath/figureA6_exit_bottom.eps", replace



		   
************************************************************************************************************************
***									FIGURE A8: ALTERNATIVE OUTCOME EXIT-VIC-RATIO		 							 ***
************************************************************************************************************************
est clear
use $datasetCEM.dta, clear

eststo m0: xi: areg exit_vic_ratio ib68.et##treated i.name_id, cl(id_squadron) a(event_id)

*create the figure
coefplot m0, keep(63.et#1.treated 64.et#1.treated 65.et#1.treated 66.et#1.treated   ///
				  67.et#1.treated 68.et#1.treated 69.et#1.treated 70.et#1.treated   ///
				  71.et#1.treated 72.et#1.treated 73.et#1.treated 74.et#1.treated 	///
				  75.et#1.treated) 													///
			 levels(90) cism vertical  												///
			 nokey xline(6.5, lcolor(red)) omitted baselevels						///
			 yline(0, lpat(dash) lcolor(grey)) 										///	     	     
			 coeflabels(63.et#1.treated = "-6" 64.et#1.treated  = "-5" 				///
						65.et#1.treated = "-4" 66.et#1.treated  = "-3" 				/// 
						67.et#1.treated = "-2" 68.et#1.treated  = "-1" 				///
						69.et#1.treated =  "0" 70.et#1.treated  =  "1" 				/// 
						71.et#1.treated =  "2" 72.et#1.treated =  "3" 				/// 
						73.et#1.treated =  "4" 74.et#1.treated =  "5" 				/// 
						75.et#1.treated =  "6")										///
						xtitle("Months since mention")

graph export "$gphpath/figureA8.eps", replace

	
