*THIS DO-FILE COMBINES THE FLIGH LOG DATA WITH THE PILOT-DAY PANEL AND RUNS THE ANALYSES

***COMBIE FLIGHT LOG DATA AND PILOT-DAY PANEL
*Use flighlog data
use "../rawdata/flightlogs.dta", replace

*Merge in mention and victory from most recent dataset
rename date_start time_id
merge 1:1 name_id time_id using "../rawdata/${dataset_daily}.dta", keepusing(pastpeerofmentioned_n vic)
drop if _merge == 2
drop _merge


***PREPARE VARIABLES
*Time relative to (first) mention
gen date_mention_all = time_id if pastpeerofmentioned_n == 1
by name_id, sort: egen date_mention = min(date_mention_all)
gen t_mention = time_id - date_mention
drop date_mention_all date_mention

*Share of combat flights
gen share_combat = combat_flights_day / allflights_day

*Label new variables
label variable t_mention   		"days between flight and mention of past peer"
label variable share_combat 	"share of flights with combat purpose per day"


*************************************************************************************************
****										FIGURE 8										 ****
*************************************************************************************************
preserve
	*Drop if no mention date (i.e. if not past peer of a mentioned pilot)
	drop if t_mention == .

	*Rdplot for 30 days before and after mention of past peer
	rdplot share_combat t_mention if t_mention>=-30 & t_mention<=30	///
		   , p(1) nbins(10 10) graph_options(xlabel(-30(15)30)	///
		   xtitle("Days before/after former peer is mentioned", size(noraml))	///
		   ytitle("Share of combat flights of total flight activity", size(normal)) legend(off))
	graph export "$gphpath/figure8.eps", replace
restore


*************************************************************************************************
****										FIGURE A7										 ****
*************************************************************************************************
preserve
	*Pool combat_flights_day of 4 and above
	replace combat_flights_day = 4 if combat_flights_day >= 4
	by combat_flights_day, sort: egen mean_vic = mean(vic)
	*Mean victories and polynomial smooth (options specified to match default on Windows)
	twoway (lpolyci vic combat_flights_day, kernel(epan2) bwidth(1.1)) (scatter mean_vic combat_flights_day, msymbol(circle_hollow))	///
		   , legend(order(3 "Mean Victories" 2 "Fitted line" 1 "95% CI") rows(1))							///
		   xtitle("Flights with combat purpose per day") ytitle("Victories per day")						///
		   xlabels(0 "0" 1 "1" 2 "2" 3 "3" 4 "4+")
	graph export "$gphpath/figureA7.eps", replace
restore
