*THIS DO-FILE COMBINES THE FLIGH LOG DATA WITH THE MONTHLY PILOT DATA AND RUNS THE ANALYSES

*************************************************************************************************
****										TABLE A10										 ****
*************************************************************************************************



*** PREPARE PANEL DATA
*Use main panel dataset
use $dataset, clear

*Standardize outcome
egen vic_std = std(vic)

*Keep variables of interest
local varlist = "mentionperiod_n pastpeerofmentioned_n pilot_quality_scwadj front exp_scw BF109* FW* t id_squadron name_id id_squadron" 
keep vic vic_std `varlist'

*Add dummy variable for dataset
gen m1 = 1

*Save as tempfile
save temp/paneldata.dta, replace



*** PREPARE FLIGHT LOGS DATA
*Flightlog data
use "../rawdata/flightlogs.dta", replace

*Merge in mention and victory from most recent dataset
rename date_start time_id
merge 1:1 name_id time_id using "../rawdata/$dataset_daily.dta", keepusing(mentionperiod_n pastpeerofmentioned_n vic pastpeerofmentioned_n pilot_quality_scwadj front exp_scw BF109* FW* t id_squadron ym_time_id)
drop if _merge == 2
drop _merge

*Collapse to monthly	  
collapse (last) id_squadron front exp_scwadj pilot_quality_scwadj BF109D BF109E BF109F BF109G BF109K FW190A FW190D	///
		 (sum) combat_flights_day allflights_day vic	///
		 (max) mentionperiod_n pastpeerofmentioned_n	///
		 , by(name_id ym_time_id)
gen t = ym_time_id		
foreach var of varlist *_day{
	local var_new = subinstr(subinstr("`var'", "_day", "", .), "_", "", .)
	rename `var' `var_new'
}

*Exp_scw in months
by name_id (t), sort: gen exp_scw = ceil(exp_scwadj/30) if _n==1	//approximate first month by dividing experience in days by 30 and round up
by name_id (t), sort: replace exp_scw = exp_scw[_n-1]+1*(t-t[_n-1]) if missing(exp_scw)
drop exp_scwadj 

*Standardize outcome
egen combatflights_std = std(combatflights)

*Keep variables of interest
local varlist = "mentionperiod_n pastpeerofmentioned_n pilot_quality_scwadj front exp_scw BF109* FW* t id_squadron name_id id_squadron"
keep combatflights_std `varlist'

*Add dummy for dataset	
gen m1 = 0

*Save as tempfile
save temp/flightlogdata.dta, replace



*** COMPARE COEFFICIENTS
*Combine datasets
use temp/paneldata.dta, clear
append using temp/flightlogdata.dta

*Create interactions
foreach var of varlist mentionperiod_n pastpeerofmentioned_n pilot_quality_scwadj front exp_scw BF109* FW*{
	gen int_`var' = m1*`var'
}

*Separate name and cluster ids for each part of the data
replace name_id		= name_id+10000 	if m1==0
replace id_squadron = id_squadron+5000	if m1==0
replace t 			= t+500 			if m1==0

*Create shared outcome variable: use flightlog var and replace if m1==1
replace combatflights_std = vic_std if m1==1

*Run regressions
est clear
	preserve
		keep if m1==0
		reghdfe combatflights_std mentionperiod_n, cl(id_squadron) a(name_id)
		local obs = e(N)
		local r2 = e(r2)
	restore	
	eststo: reghdfe combatflights_std mentionperiod_n int_mentionperiod_n, cl(id_squadron) a(name_id)
		estadd local aircraft "N"
		estadd local quality "N"
		estadd local front "N"
		estadd local experience "N"
		estadd local pilotFE "Y"
		estadd local squadronFE "N"
		estadd local timeFE "N"
		estadd scalar obs_fl `obs'
		estadd scalar r2_fl `r2'

	preserve
		keep if m1==0
		reghdfe combatflights_std mentionperiod_n pastpeerofmentioned_n pilot_quality_scwadj front exp_scw BF109* FW*, cl(id_squadron) a(name_id id_squadron)
		local obs = e(N)
		local r2 = e(r2)
	restore	
	eststo: reghdfe combatflights_std mentionperiod_n int_mentionperiod_n pastpeerofmentioned_n int_pastpeerofmentioned_n pilot_quality_scwadj int_pilot_quality_scwadj front int_front exp_scw int_exp_scw BF109* int_BF109* FW* int_FW*, cl(id_squadron) a(name_id id_squadron)
		estadd local aircraft "Y"
		estadd local quality "Y"
		estadd local front "Y"
		estadd local experience "Y"
		estadd local pilotFE "Y"
		estadd local squadronFE "Y"
		estadd local timeFE "N"
		estadd scalar p_equal = r(table)[4, 4]
		estadd scalar p_zero = r(table)[4, 3]
		estadd scalar obs_fl `obs'
		estadd scalar r2_fl `r2'

	preserve
		keep if m1==0
		reghdfe combatflights_std pastpeerofmentioned_n pilot_quality_scwadj front exp_scw BF109* FW*, cl(id_squadron) a(name_id id_squadron t)
		local obs = e(N)
		local r2 = e(r2)
	restore	
	eststo: reghdfe combatflights_std pastpeerofmentioned_n int_pastpeerofmentioned_n pilot_quality_scwadj int_pilot_quality_scwadj front int_front exp_scw int_exp_scw BF109* int_BF109* FW* int_FW*, cl(id_squadron) a(name_id id_squadron t)
		estadd local aircraft "Y"
		estadd local quality "Y"
		estadd local front "Y"
		estadd local experience "Y"
		estadd local pilotFE "Y"
		estadd local squadronFE "Y"
		estadd local timeFE "Y"
		estadd scalar p_equal = r(table)[4, 2]
		estadd scalar p_zero = r(table)[4, 1]
		estadd scalar obs_fl `obs'
		estadd scalar r2_fl `r2'

	

*** PANEL, VIC STD
*Panel data
use temp/paneldata.dta, clear

***PANEL B: VICTORIES
local outcome = "vic_std"
xtset name_id t
*Col 1
eststo: xi: reghdfe `outcome' mentionperiod_n, cl(id_squadron) a(name_id)
	local obs = e(N)
	local r2 = e(r2)
	estadd local aircraft "N"
	estadd local quality "N"
	estadd local front "N"
	estadd local experience "N"
	estadd local pilotFE "Y"
	estadd local squadronFE "N"
	estadd local timeFE "N"
	estadd scalar obs_fl `obs'
	estadd scalar r2_fl `r2'

*Col 5
eststo: xi: reghdfe `outcome' mentionperiod_n pastpeerofmentioned_n pilot_quality_scwadj front exp_scw BF109* FW*, cl(id_squadron) a(name_id id_squadron)
	local obs = e(N)
	local r2 = e(r2)
	estadd local aircraft "Y"
	estadd local quality "Y"
	estadd local front "Y"
	estadd local experience "Y"
	estadd local pilotFE "Y"
	estadd local squadronFE "Y"
	estadd local timeFE "N"
	estadd scalar p_zero = r(table)[4, 2]
	estadd scalar obs_fl `obs'
	estadd scalar r2_fl `r2'

	
*Col 6
eststo: xi: reghdfe `outcome' pastpeerofmentioned_n pilot_quality_scwadj front exp_scw BF109* FW*, cl(id_squadron) a(name_id id_squadron t)
	local obs = e(N)
	local r2 = e(r2)
	estadd local aircraft "Y"
	estadd local quality "Y"
	estadd local front "Y"
	estadd local experience "Y"
	estadd local pilotFE "Y"
	estadd local squadronFE "Y"
	estadd local timeFE "Y"
	estadd scalar p_zero = r(table)[4, 1]
	estadd scalar obs_fl `obs'
	estadd scalar r2_fl `r2'

	

*** CREATE TABLE

esttab using "$gphpath/tableA10_temp1.tex", replace																									///
	   se noobs star(* .1 ** .05 *** .01) b(%9.3f) sfmt(%9.3f %9.3f %9.0fc %9.3f) nomtitles varwidth(34) modelwidth(10) nonotes compress booktabs	///
	   keep(mentionperiod_n pastpeerofmentioned_n)																									///
	   varlabels(mentionperiod_n "Mention period" pastpeerofmentioned_n "Former peer gets mentioned (a)")											///
	   scalars("p_zero Coefficient (a) = 0" "p_equal Coefficients (a) equal across samples" 														///
	   "obs_fl \textit{N}" "r2_fl \textit{\$R^2$}" "aircraft \textit{Aircraft type}" "quality \textit{Pilot quality}" "front \textit{Eastern front}" "experience \textit{Experience}" "pilotFE \textit{Pilot FE}" "squadronFE \textit{Squadron FE}" "timeFE \textit{Time FE}")


filefilter "$gphpath/tableA10_temp1.tex" "$gphpath/tableA10_temp2.tex", 				///
		   from("\BSmidrule\r\nMention")												///
		   to("\BSmidrule & \BSmulticolumn{3}{c}{Flight log sample: combat flights} & \BSmulticolumn{3}{c}{Full sample: victories}\BS\BS \BScmidrule(lr){2-4} \BScmidrule(lr){5-7} Mention") replace										   
filefilter "$gphpath/tableA10_temp2.tex" "$gphpath/tableA10_temp3.tex", 				///
		   from("\BStextit{N}") to("\BSmidrule \BStextit{N}") replace										   
filefilter "$gphpath/tableA10_temp3.tex" "$gphpath/tableA10.tex", 						///
		   from("Coefficient (a) = 0")													///
		   to("\BSmulticolumn{7}{l}{\BSunderline{\BStextit{p-values}}}\BS\BS Coefficient (a) = 0") replace										   
												   
erase "$gphpath/tableA10_temp1.tex"
erase "$gphpath/tableA10_temp2.tex"
erase "$gphpath/tableA10_temp3.tex"
		  
		   
