*      This script tests creates the helper files baselists_monthly.dta,
*												  allpeers_base_monthly.dta,
*												  basepeers_only_monthly in currentdata/temp


*********************************************************************************
* 1. create the monthly base lists
******************************************************************************** 

*load newest version of the monthly data that is generated from daily data
use $dataset_input.dta, clear

keep name_id t base_id
drop if base_id ==.

*number the pilots within a base
bysort base_id t: gen pilot_num = _n
su pilot_num
local n = r(max)-1

br name_id t base_id pilot_num

*get name_ids of all pilots in the group
forvalues i = 1/`n' {
	gen peer_comp_h_`i' = name_id if pilot_num == `i'
	bysort base_id t: egen peer_comp`i' = max(peer_comp_h_`i')
	drop peer_comp_h_`i'
}
drop pilot_num

*reshape to create extra observations for each pilot-month-peer combination 
greshape long peer_comp, i(name_id t) j(j)
drop j
drop if peer_comp ==.
drop if name_id == peer_comp 

save temp/baselists_monthly.dta, replace

********************************************************************************
* 2. create the monthly allpeers base list
******************************************************************************** 

*find out how many months are in the war
use $dataset_input.dta, clear
su t // it's 69 months
local n = r(max)

*use squadron list as a starting point
use temp/baselists_monthly.dta, clear 

*only keep the first month that pilot and peer are in the same squadron
gegen first_month = min(t), by(name_id peer_comp)
gsort name_id peer_comp t
br
drop base_id
keep if t == first_month
drop t

*fill up the pilot-peer-month panel
forvalues i = 1/`n' {
	gen month`i' = `i'
}

greshape long month, i(name_id peer_comp) j(j)
drop j
rename month t

*only keep observations starting with the first month 
keep if t >= first_month
drop first_month

save temp/allpeers_base_monthly.dta, replace


********************************************************************************
* 3. create the monthly list of only base peers, not squadron or group peers
******************************************************************************** 
use temp/allpeers_base_monthly.dta, clear

*merge in lists of group peers, and keep those that are only base peers
merge 1:1 name_id peer_comp t using temp/allpeers_group_monthly 
keep if _m == 1
drop _m

merge 1:1 name_id peer_comp t using temp/allpeers_monthly
keep if _m==1
drop _m

compress
save temp/basepeers_only_monthly.dta, replace

