*       This script creates the helper files grouplist_monthly.dta,
*											 allpeers_group_monthly.dta,
*											 grouppeers_only_monthly.dta in currentdata/temp


*********************************************************************************
* 1. create the monthly grouplist
******************************************************************************** 

*load newest version of the monthly data that is generated from daily data
use $dataset_input.dta, clear

keep name_id t id_group
drop if id_group ==.

*number the pilots within a group
bysort id_group t: gen pilot_num = _n
su pilot_num
local n = r(max)-1

*get name_ids of all pilots in the group
forvalues i = 1/`n' {
	gen peer_comp_h_`i' = name_id if pilot_num == `i'
	bysort id_group t: egen peer_comp`i' = max(peer_comp_h_`i')
	drop peer_comp_h_`i'
}
drop pilot_num

*reshape to create extra observations for each pilot-month-peer combination 
greshape long peer_comp, i(name_id t) j(j)
drop j
drop if peer_comp ==.
drop if name_id == peer_comp 

save temp/grouplists_monthly.dta, replace

********************************************************************************
* 2. create the monthly allpeers group list
******************************************************************************** 

*find out how many months are in the war
use $dataset_input.dta, clear
su t // it's 69 months
local n = r(max)

*use squadron list as a starting point
use temp/grouplists_monthly.dta, clear 

*only keep the first month that pilot and peer are in the same squadron
gegen first_month = min(t), by(name_id peer_comp)
gsort name_id peer_comp t

drop id_group
keep if t == first_month
drop t

*fill up the pilot-peer-month panel
forvalues i = 1/`n' {
	gen month`i' = `i'
}

greshape long month, i(name_id peer_comp) j(j)
drop j
rename month t

*only keep observations starting with the first month 
keep if t >= first_month
drop first_month

save temp/allpeers_group_monthly.dta, replace


********************************************************************************
* 3. create the monthly list of only grouppeers, not squadron peers
******************************************************************************** 
use temp/allpeers_group_monthly.dta, clear

*merge in lists of squadron peers, and only keep those that are group peers
merge 1:1 name_id peer_comp t using temp/allpeers_monthly.dta
keep if _m == 1
drop _m

compress
save temp/grouppeers_only_monthly.dta,replace
