*       This script creates the helper files squadronlist_monthly.dta and allpeers_monthly.dta in currentdata/temp


*********************************************************************************
* 1. create the monthly squadronlist
******************************************************************************** 

*load newest version of the monthly data that is generated from daily data
use $dataset_input.dta, clear

keep name_id t id_squadron
drop if id_squadron == .

*number the pilots within a squadron
bysort id_squadron t: gen pilot_num = _n
su pilot_num
local n = r(max)-1

*get name_ids of all pilots in the squadron
forvalues i = 1/`n' {
	gen peer_comp_h_`i' = name_id if pilot_num == `i'
	bysort id_squadron t: egen peer_comp`i' = max(peer_comp_h_`i')
	drop peer_comp_h_`i'
}
drop pilot_num

*reshape to create extra observations for each pilot-month-peer combination 
greshape long peer_comp, i(name_id t) j(j)
drop j
drop if peer_comp ==.
drop if name_id == peer_comp 

save temp/squadronlist_monthly.dta, replace

********************************************************************************
* 2. create the monthly allpeers list
******************************************************************************** 

*find out how many months are in the war
use $dataset_input.dta, clear
su t // it's 69 months
local n = r(max)

*use squadron list as a starting point
use temp/squadronlist_monthly.dta, clear 

*only keep the first month that pilot and peer are in the same squadron
gegen first_month = min(t), by(name_id peer_comp)
gsort name_id peer_comp t

drop id_squadron
keep if t == first_month
drop t

*fill up the pilot-peer-month panel
forvalues i = 1/`n' {
	gen month`i' = `i'
}

greshape long month, i(name_id peer_comp) j(j)
drop j
rename month t

*only keep observations starting with the first month 
keep if t >= first_month
drop first_month

save temp/allpeers_monthly.dta, replace
