*       This script creates a program to move the data into an event-time shape and adds a cluster variable

********************************************************************************
*** Define the program to reshape data to event windows and create graphs
******************************************************************************** 

program drop _all
program define gen_windows

********************************************************************************
*** 1. line up treated pilots in event time
********************************************************************************
use `3'.dta, clear

*create variable capturing the mentioned pilot
**get the number of peers
gen peer_num = 0

preserve 

	use `3', clear
	levelsof name_id if treated == 1, local(treat_id)

restore

foreach i of local treat_id {

	capture noisily replace peer_num = peer_num + 1 if `1'_`i' == 1

}


su peer_num 
local N `r(max)' // get number of peers
disp "`N'"

**get name_ids of all peers 
forvalues n = 1/`N' {
	
	gen peer_id`n' = .
}


foreach i of local treat_id {
	
	capture noisily replace peer_id1 = `i' if `1'_`i' == 1 & peer_id1 == .
	
}
	
	
forvalues n = 2/`N' {
	
	foreach i of local treat_id {
		
		local m = `n' - 1
	
		capture noisily replace peer_id`n' = `i' if `1'_`i' == 1     & peer_id`n' == . & ///
									peer_id`m' != .  & peer_id`m' < `i'	
	}
}

*only keep observations of past peers of treated
keep if `1' == 1
keep name_id t peer_id*


*fill up to a full panel of event-months
sort name_id t
gen event_num = _n
gen event_time = 0

su event_num

local i `r(max)' // get number of events
disp "`i'"

local j = `i' + 69 // get number of events plus number of months in war
disp "`j'"

local k = `i' + 1 // get number of events plus 1
disp "`k'"


*create extra event with full set of months to make tsfill work properly
set obs `j' //  (i.e. number of events) + 69 (number of months in war)
recode event_num . = `k'
replace t = _N - _n + 1 if event_num == `k'

xtset event_num t

tsfill, full

drop if event_num == `k'


* add the name_id to all extra months
gegen event_name = max(name_id), by(event_num)
replace name_id = event_name
drop event_name

* add the peer_id to all extra months
forvalues n = 1/`N' {
	gegen event_peer_id`n' = max(peer_id`n'), by(event_num)
	drop peer_id`n'
}

* fill up the event_time
gen event_month_h = t if event_time == 0
gegen event_month = max(event_month_h), by(event_num)
drop event_month_h

replace event_time = t - event_month
drop event_month

*only keep pilot-months that actually exist in  panel
merge m:1 name_id t using `4'
keep if _m == 3
drop _m

capture: gen treated = 1
capture: replace treated = 1

tab event_time

save eventtime_treated_test.dta, replace


********************************************************************************
*** 2. line up matched pilots in event time
********************************************************************************
use `3', clear

*create variable capturing the mentioned pilot
**get the number of peers
gen peer_num = 0

preserve 

	use `3', clear
	levelsof name_id if matched == 1, local(match_id)

restore

foreach i of local match_id {

	capture noisily replace peer_num = peer_num + 1 if `2'_`i' == 1

}


su peer_num 
local N `r(max)' // get number of peers
disp "`N'"

**get name_ids of all peers 
forvalues n = 1/`N' {
	
	gen peer_id`n' = .
}


foreach i of local match_id {
	
	capture noisily replace peer_id1 = `i' if `2'_`i' == 1 & peer_id1 == .
	
}
	
	
forvalues n = 2/`N' {
	
	foreach i of local match_id {
		
		local m = `n' - 1
	
		capture noisily replace peer_id`n' = `i' if `2'_`i' == 1     & peer_id`n' == . & ///
									peer_id`m' != .  & peer_id`m' < `i'	
	}
}


*only keep observations of past peers of matched
keep if `2' == 1
keep name_id t peer_id*

*fill up to a full panel of event-months
sort name_id t
gen event_num = _n
gen event_time = 0

su event_num

local i `r(max)' // get number of events
disp "`i'"

local j = `i' + 69 // get number of events plus number of months in war
disp "`j'"

local k = `i' + 1 // get number of events plus 1
disp "`k'"

*create extra event with full set of months to make tsfill work properly
set obs `j' // (i.e. number of events) + 69 (number of months in war)
recode event_num . = `k'
replace t = _N - _n + 1 if event_num == `k' 

xtset event_num t

tsfill, full

drop if event_num == `k'


* add the name_id to all extra months
gegen event_name = max(name_id), by(event_num)
replace name_id = event_name
drop event_name

* add the peer_id to all extra months
forvalues n = 1/`N' {
	gegen event_peer_id`n' = max(peer_id`n'), by(event_num)
	drop peer_id`n'
}

* fill up the event_time
gen event_month_h = t if event_time == 0
gegen event_month = max(event_month_h), by(event_num)
drop event_month_h

replace event_time = t - event_month
drop event_month

*only keep pilot-months that actually exist in  panel
merge m:1 name_id t using `4'
keep if _m == 3
drop _m

capture: gen treated = 0
capture: replace treated = 0


tab event_time


********************************************************************************
*** 3. append event windows from treatment and control
********************************************************************************

append using eventtime_treated_test.dta

gen post = 0
replace post = 1 if event_time >= 0

gen post_x_treatment = post * treated

gsort treated event_num event_time

********************************************************************************
*** 4. erase intermediate files
********************************************************************************

erase eventtime_treated_test.dta

end





